clear
set more off
cd "E:\Dropbox\feyrer replication\replication files"

use BLS_Distance_working,clear
keep if id==1

**************************
*generate donut production variables
***************************

rename d0newfossilval_cap d0newval_cap
gen double d0newval=d0newval_cap*d0employ
foreach x in 20 40 60 80 100 120 140 160 180 200 {
local r=`x'-20
gen double d`x'newval=d`x'newfossilval_cap*d`x'employ                 //finds new production value for each radius
gen double d`r'`x'newval=d`x'newval - d`r'newval                      //finds new value for each donut (using var created in above line)
gen double d`r'`x'newval_capi=(d`x'newval - d`r'newval)/(l.d0employ)  //finds new value for each donut per population of county i. 
gen double d`r'`x'employ=d`x'employ - d`r'employ                      //finds #employees in each donut.
}

gen double d040newval_capi=(d020newval + d2040newval)/(l.d0employ)    //new production in 0-40 donut
gen double d040employ= d020employ + d2040employ						  //employment in 0-40 donut


*****************************
*Results Tables and Graphs
*****************************


foreach var in d_d0wages_cap d_d0irsoth_cap {

reghdfe `var' L(0/1).d0newval_cap L(0/1).d040newval_capi L(0/1).d4060newval_capi L(0/1).d6080newval_capi L(0/1).d80100newval_capi L(0/1).d100120newval_capi L(0/1).d120140newval_capi L(0/1).d140160newval_capi L(0/1).d160180newval_capi L(0/1).d180200newval_capi if id==1 & sample, cluster(fips year) a(fips year)

**find avg. pop in distance bins 
foreach x in 0 040 4060 6080 80100 100120 120140 140160 160180 180200 {
qui sum d`x'employ if e(sample)==1  
local d`x'pop=r(mean)
}

**create cumulative propogation estimates and confidence intervals for each donut
lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi
local ci_lower_040 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_040 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_040 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi
local ci_lower_4060 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_4060 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_4060 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi
local ci_lower_6080 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_6080 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_6080 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi
local ci_lower_80100 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_80100 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_80100 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi + (`d100120pop'/`d0pop')*d100120newval_capi
local ci_lower_100120 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_100120 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_100120 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi + (`d100120pop'/`d0pop')*d100120newval_capi + (`d120140pop'/`d0pop')*d120140newval_capi
local ci_lower_120140 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_120140 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_120140 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi + (`d100120pop'/`d0pop')*d100120newval_capi + (`d120140pop'/`d0pop')*d120140newval_capi + (`d140160pop'/`d0pop')*d140160newval_capi
local ci_lower_140160 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_140160 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_140160 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi + (`d100120pop'/`d0pop')*d100120newval_capi + (`d120140pop'/`d0pop')*d120140newval_capi + (`d140160pop'/`d0pop')*d140160newval_capi + (`d160180pop'/`d0pop')*d160180newval_capi
local ci_lower_160180 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_160180 = (r(estimate) + invt(r(df),.975)*r(se))/1000
local se_160180 = r(se)

lincom d0newval_cap + (`d040pop'/`d0pop')*d040newval_capi + (`d4060pop'/`d0pop')*d4060newval_capi + (`d6080pop'/`d0pop')*d6080newval_capi + (`d80100pop'/`d0pop')*d80100newval_capi + (`d100120pop'/`d0pop')*d100120newval_capi + (`d120140pop'/`d0pop')*d120140newval_capi + (`d140160pop'/`d0pop')*d140160newval_capi + (`d160180pop'/`d0pop')*d160180newval_capi + (`d180200pop'/`d0pop')*d180200newval_capi
local ci_lower_180200 = (r(estimate) + invt(r(df),.025)*r(se))/1000
local ci_upper_180200 = (r(estimate) + invt(r(df),.975)*r(se))/1000
di `ci_upper_180200'
local se_180200 = r(se)

**generate results graphs
preserve
regsave,ci
drop if strpos( var,"L.")!=0
gen distance=0 if var=="d0newval_cap"
replace distance=40 if var=="d040newval_capi"
replace distance=20*_n if distance==.

replace coef=coef/1000
replace ci_lower=ci_lower/1000
replace ci_upper=ci_upper/1000

gen pop=.
gen ci_lower_cum=.
gen ci_upper_cum=.
gen se_cum=.
replace pop=`d0pop' if var=="d0newval_cap"
foreach x in 040 4060 6080 80100 100120 120140 140160 160180 180200 {
replace pop= `d`x'pop' if var=="d`x'newval_capi"

replace ci_lower_cum = `ci_lower_`x'' if var=="d`x'newval_capi"
replace ci_upper_cum = `ci_upper_`x'' if var=="d`x'newval_capi"
replace se_cum=`se_`x'' if var=="d`x'newval_capi"
}

replace ci_lower_cum=ci_lower if var =="d0newval_cap"
replace ci_upper_cum=ci_upper if var =="d0newval_cap"
replace se_cum=stderr if var =="d0newval_cap"

gen total_prop=pop*coef/`d0pop'
gen cumulative_prop=total_prop[1]
replace cumulative_prop=total_prop[_n]+ cumulative_prop[_n-1] if _n>1

gen ci_lower_totalprop=ci_lower*pop/`d0pop'
gen ci_upper_totalprop=ci_upper*pop/`d0pop'

**per capita effect by donut
twoway (rarea ci_lower ci_upper dist, color(gs11)) (scatter coef dist,lpattern(solid) mcolor(maroon)) (line coef dist,lpattern(solid) lcolor(black)), ///
xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

**total propagation by donut (ie within donut only)
twoway (rarea ci_lower_totalprop ci_upper_totalprop dist, color(gs11)) (scatter total_prop dist,lpattern(solid) mcolor(maroon)) (line total_prop dist,lpattern(solid) lcolor(black)), ///
xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

**cumulative propagation by donut
twoway (rarea ci_lower_cum ci_upper_cum dist, color(gs11)) (line cumulative_prop dist,lpattern(solid) lcolor(black)) (scatter cumulative_prop dist,lpattern(solid) mcolor(maroon))  ///
, xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

restore

}


****************************
*replicate original FMS OLS results (used in graphs below)
****************************

*append results from increasing 
foreach d in 0 20 40 60 80 100 120 140 160 180 200 {
qui xtivreg2 d_d`d'wages_cap L(0/1).d`d'newfossilval_cap yeardum* if id==1 & sample, cluster(fips year) fe partial(yeardum*)
}

foreach d in 0 20 40 60 80 100 120 140 160 180 200 {
xtivreg2 d_d`d'irsoth_cap L(0/1).d`d'newfossilval_cap yeardum* if id==1 & sample, cluster(fips year) fe partial(yeardum*)
}

****************************
*recreate figure 2, panels c and d, and figure 3, panels c and f.
****************************
use fms_results_figures,clear

*fig 2 panel c
twoway (line dwages dist,lpattern(solid) lcolor(black)) (scatter dwages dist,lpattern(solid) mcolor(maroon)) , xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

*fig 2 panel d
twoway (line dirsother dist,lpattern(solid) lcolor(black)) (scatter dirsother dist,lpattern(solid) mcolor(maroon)), xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

*fig 3 panel c
twoway (rarea ci_lower_cum_wages ci_upper_cum_wages dist, color(gs11)) (rarea wageslower_fms wagesupper_fms dist, color(gs11)) (line wages_fms dist,lpattern(solid) lcolor(black)) (line cumulative_prop_wages dist,lpattern(solid) lcolor(black)) (scatter wages_fms dist,lpattern(solid) mcolor(maroon)) (scatter cumulative_prop_wages dist,lpattern(solid) mcolor(maroon)), xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)

*fig 3 panel f
twoway (rarea ci_lower_cum_irsoth ci_upper_cum_irsoth dist, color(gs11)) (rarea irsotherlower_fms irsotherupper_fms dist, color(gs11)) (line irsother_fms dist,lpattern(solid) lcolor(black)) (line cumulative_prop_irsoth dist,lpattern(solid) lcolor(black)) (scatter irsother_fms dist,lpattern(solid) mcolor(maroon)) (scatter cumulative_prop_irsoth dist,lpattern(solid) mcolor(maroon)), xlabel(0(20)200) ytitle("2014 US$ (Thousands)") xtitle("Distance") legend(off)


